Documentation
¶
Index ¶
- func Disconnect(t *testing.T, proxyName string, duration time.Duration) (started, stopped func())
- func DisconnectWithStartStartedStopped(t *testing.T, proxyName string, duration time.Duration) (disconnect, awaitStarted, awaitStopped func())
- func DisconnectWithStartedStopped(t *testing.T, proxyName string, block, startIn, duration time.Duration) (awaitStarted, awaitStopped func())
- func DisconnectWithStopped(t *testing.T, proxyName string, block, timeout, duration time.Duration) (wait func())
- type Proxy
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Disconnect ¶
func DisconnectWithStartStartedStopped ¶
func DisconnectWithStartStartedStopped(t *testing.T, proxyName string, duration time.Duration) (disconnect, awaitStarted, awaitStopped func())
block current thread timeout: how long the asynchronous goroutine needs to wait until it disables the connection duration: how long the asynchronous goroutine wait suntil it reenables the connection
func DisconnectWithStartedStopped ¶
func DisconnectWithStartedStopped(t *testing.T, proxyName string, block, startIn, duration time.Duration) (awaitStarted, awaitStopped func())
https://github.com/Shopify/toxiproxy#toxics block current thread timeout: how long the asynchronous goroutine needs to wait until it disables the connection duration: how long the asynchronous goroutine wait suntil it reenables the connection
func DisconnectWithStopped ¶
func DisconnectWithStopped(t *testing.T, proxyName string, block, timeout, duration time.Duration) (wait func())
https://github.com/Shopify/toxiproxy#toxics block current thread timeout: how long the asynchronous goroutine needs to wait until it disables the connection duration: how long the asynchronous goroutine wait suntil it reenables the connection